@@ -3,10 +3,16 @@
 require_once('tilib.php');
 require_once('lib/nusoap.php');
 
+function myErrorHandler($errno, $errstr, $errfile, $errline)
+{
+	// We are not caring much.
+	LG("Error\n");
+}
+
 // Define the method as a PHP function
 function ProxyToolLaunch($ImsHeader, $ProxyToolLaunch) {
 
-    LG("\n------------ Starting ProxyTool Launch -----------\n\n");
+    LG("\n------------ Starting X   ProxyTool Launch -----------\n\n");
     
     ob_start(LG);
     echo("ProxyToolLaunch\n");
@@ -29,21 +35,32 @@ function ProxyToolLaunch($ImsHeader, $ProxyToolLaunch) {
 
     // Parse the input parameters - a sample of the input parameters is at the 
     // Bottom of this message
-    $lidVal  = $ProxyToolLaunch["ContextualSettings"]["LaunchProfile"]["LaunchIdentifier"];
-    $roleVal = $ProxyToolLaunch["ContextualSettings"]["LaunchProfile"]["Role"];
-    $contextVal = $ProxyToolLaunch["ContextualSettings"]["DeliveryContextProfile"]["IMSSourcedid"]["SourceID"];
-    $eidVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["IMSSourcedid"]["SourceID"];
-    $idVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["Userid"];
-    $fnVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["FirstName"];
-    $lnVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["LasttName"];
-
-    LG("Context (SiteId) = $contextVal\n");
-    LG("LaunchIdentifier = $lidVal\n");
-    LG("Role = $roleVal\n");
-    LG("Enterprise ID = $eidVal\n");
-    LG("User ID = $idVal\n");
-    LG("First Name = $fnVal\n");
-    LG("Last Name = $lnVal\n");
+    if (  $ProxyToolLaunch["ContextualSettings"] ) {
+       if ( $ProxyToolLaunch["ContextualSettings"]["LaunchProfile"] ) {
+         $lidVal  = $ProxyToolLaunch["ContextualSettings"]["LaunchProfile"]["LaunchIdentifier"];
+         LG("LaunchIdentifier = $lidVal\n");
+         $roleVal = $ProxyToolLaunch["ContextualSettings"]["LaunchProfile"]["Role"];
+         LG("Role = $roleVal\n");
+       }
+       if ( $ProxyToolLaunch["ContextualSettings"]["DeliveryContextProfile"] ) {
+         if ( $ProxyToolLaunch["ContextualSettings"]["DeliveryContextProfile"]["IMSSourcedid"] ) {
+           $contextVal = $ProxyToolLaunch["ContextualSettings"]["DeliveryContextProfile"]["IMSSourcedid"]["SourceID"];
+           LG("Context (SiteId) = $contextVal\n");
+         }
+       }
+       if ( $ProxyToolLaunch["ContextualSettings"]["UserProfile"] ) {
+         if ( $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["IMSSourcedid"] ) {
+           $eidVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["IMSSourcedid"]["SourceID"];
+           LG("Enterprise ID = $eidVal\n");
+         }
+         $idVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["Userid"];
+         LG("User ID = $idVal\n");
+         $fnVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["FirstName"];
+         LG("First Name = $fnVal\n");
+         $lnVal = $ProxyToolLaunch["ContextualSettings"]["UserProfile"]["LasttName"];
+         LG("Last Name = $lnVal\n");
+      }
+    }
     
     $parms = "";
     if ( isset($contextVal) ) $parms .= "&SiteId=".$contextVal;
@@ -59,6 +76,7 @@ function ProxyToolLaunch($ImsHeader, $ProxyToolLaunch) {
     $toolpath .= htmlspecialchars($parms);
     LG("Tool Path= $toolpath \n");
 
+LG("HO THERE\n");
     // Produce a reasonable return value
     $retval = 
 	array ( 
@@ -89,6 +107,14 @@ function ProxyToolLaunch($ImsHeader, $ProxyToolLaunch) {
 	      ) // End of HeaderInfoResponse
          ) ;
 
+LG("HI THERE\n");
+
+    ob_start(LG);
+    echo("Returning\n");
+    var_dump($retval);
+    echo("\n");
+    ob_end_clean();
+
     return $retval;
 }
 
